package com.faraphel.tasks_valider.ui.screen.room

import android.net.wifi.p2p.WifiP2pManager
import android.util.Log
import androidx.compose.foundation.layout.Column
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import com.faraphel.tasks_valider.connectivity.wifi_p2p.WifiP2pHelper
import com.faraphel.tasks_valider.ui.screen.tasks.TaskGroupScreen


/**
 * This screen allow the user to create a room
 */
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun RoomHostScreen(wifiP2pHelper: WifiP2pHelper) {
    val expanded = remember { mutableStateOf(false) }
    val isCreated = remember { mutableStateOf(false) }

    // if the group have been created, display the group screen
    if (isCreated.value) {
        TaskGroupScreen()
        return
    }

    Column {
        ExposedDropdownMenuBox(
            expanded = expanded.value,
            onExpandedChange = { value -> expanded.value = !value }
        ) {
            DropdownMenuItem(
                text = { Text("ISRI") },
                onClick = {}
            )
            DropdownMenuItem(
                text = { Text("MIAGE") },
                onClick = {}
            )
        }

        Button(onClick = {
            // create a new WiFi-Direct group
            wifiP2pHelper.recreateGroup(object : WifiP2pManager.ActionListener {
                override fun onSuccess() {
                    Log.i("room", "group created !")
                    // mark the group as created
                    isCreated.value = true
                }
                override fun onFailure(reason: Int) {
                    Log.e("room", "error while creating group. Reason: $reason")
                }
            })
        }) {
            Text("Create")
        }
    }

}
